# Kegbot Server

This is Kegbot Server, a backend and web interface for monitoring
and managing kegged beverages.

**Official repository:** https://github.com/Kegbot/kegbot-server/


## Quick start

Super quick start instructions:

```
$ mkvirtualenv kb
(kb) $ pip install kegbot
(kb) $ setup-kegbot.py
(kb) $ kegbot runserver
Development server is running at http://localhost:8000/
```

For much more detail, see the complete [Kegbot Server documentation](http://kegbot.org/docs/server/).


## Documentation and Help

Please see our main website, http://kegbot.org/, for
[documentation](http://kegbot.org/docs), the
[Kegbot Forum](http://kegbot.org/kegbb/), and the
[Kegbot Blog](http://kegbot.org/blog/).

You can also find us on **#kegbot** on freenode IRC.

You should definitely follow [@kegbot](http://twitter.com/kegbot) on
Twitter, all the cool kids are.


## Related Projects

* [Kegboard](https://github.com/Kegbot/kegboard): Firmware and schematics
  for the Kegbot controller board.
* [Kegbot Android app](https://github.com/Kegbot/kegbot-android): Kegtap,
  the Kegbot manager app for Android.


## License and Copyright

This software is offered under the **GPLv2** license.  Your use of
Kegbot Server constitutes your agreement to that license.  Please see
``LICENSE.txt`` for the full license.

Code and documentation are **Copyright 2014 Bevbot LLC**,
unless otherwise noted.  Graphics and images distributed with Kegbot,
such as the Kegbot logo, are also copyrighted works of Bevbot LLC
unless otherwise noted, and may not be reused without permission.


## Contributing

We love getting patches! Send us a pull request, or hop on to IRC if
you'd like to chat about something substantial.

[![Build Status](https://travis-ci.org/Kegbot/kegbot-server.png?branch=master)](https://travis-ci.org/Kegbot/kegbot-server)

